@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # flake8:noqa
 # pylint: skip-file
-"""Expose usefull features."""
+"""Expose useful features."""
 
 from .._imcache import IMCache
 from ._files import File, cwdfiles
@@ -12,8 +12,8 @@ from ._helpers import (
     last_first,
     normalize_space,
     parse_placeholders,
-    unicode_to_utf8tex as to_utf8tex,
 )
+from ._helpers import unicode_to_utf8tex as to_utf8tex
 
 # alias (to keep backwards compatibility)
 fmtbib = _fmtbib
